<?php

/*//. KatePKG - A GUI (GTK2) Package Manger for KateOS.
Written by Bob Majdak Jr <bob@kateos.org>.

This program is released under the GNU GPL.

See $PREFIX/bin/katepkg for details .//*/

function package_dialog_uninstall_check() {

	global $w;
	global $selected;
	
	$w->ui->set_sensitive(FALSE);	
	
	//. check each selected package.
	foreach($selected as $pkg) {
	
		$info = package_read_info($pkg,TRUE);

		if(!count($info['dependents'])) { continue; }		
		
		//. build the dialog.
		$dialog = new packageMegaConfirmDialog(_('Dependent Packages Found'),'question',sprintf("%s <b>%s</b>",_('The following packages depend on'),$pkg));
		$dialog->yes->set_label(_('Remove'));
		$dialog->no->set_label(_('Ignore'));
		
		//. list dependent packages.
		foreach($info['dependents'] as $dep) {
			$dialog->status->append_text(sprintf("%s\n",$dep));
		}

		$dialog->show_all();
		
		switch($dialog->run()) {
			case(Gtk::RESPONSE_YES): {
				//.  remove the dependents too.
				$dialog->destroy(); $dialog = FALSE;
				foreach($info['dependents'] as $dep) {
					if(!in_array($dep,$selected)) {
						katepkg_dprintf("%s added to list\n",$dep);
						$selected[] = $dep;
					}
				}
				break;
			}
			case(Gtk::RESPONSE_NO): {
				//. keep the dependents.
				$dialog->destroy(); $dialog = FALSE;
				break;
			}
			default: {
				$dialog->destroy(); $dialog = FALSE;
				$w->ui->set_sensitive(TRUE);
				return TRUE;
				break;			
			}
		}
		
	}
	
	//. making it out the back side of the loop means the user never clicked cancel, so we can proceed
	//. with the uninstall.
	package_dialog_uninstall_confirm();
		
	//. the dialog has already been destroyed by each reponse and the main UI will be given back by the
	//. uninstall function.

}

function package_dialog_uninstall_confirm() {
	
	global $w;
	global $selected;
	
	//. turn off the UI.
	$w->ui->set_sensitive(FALSE);	
	
	//. build
	$dialog = new packageMegaConfirmDialog(_('Confirm Removal'),'question',_('Are you sure you wish to uninstall the selected packages?'));
	$dialog->cancel->destroy();

	//. list packages.
	foreach($selected as $pkg) {
		$dialog->status->append_text(sprintf("%s\n",$pkg));
	}	
	
	$dialog->show_all();

	switch($dialog->run()) {
		case(Gtk::RESPONSE_YES): {
			//. uninstall. next function will return the UI.
			$dialog->destroy(); $dialog = FALSE;
			package_dialog_uninstall();
			break;
		}
		default: {
			//. cancel and give back the UI.
			$dialog->destroy(); $dialog = FALSE;
			$w->ui->set_sensitive(TRUE);
			break;
		}
	}
	
}

function package_dialog_uninstall() {

	//. this function handles the uninstallation of packages from the system.
	
	global $w;
	global $selected,$config;
	
	$errc = $opiter = 0;
	$status = FALSE;
	$opcount = count($selected);
	
	$w->ui->set_sensitive(FALSE);
	
	//. setup the dialog.
	$dialog = new packageMegaProgressDialog(_('Uninstalling Packages'),'uninstallation',_('Removing packages from the system'));
	$dialog->totalprogress->destroy();
	$dialog->cancel->connect_simple('clicked',array($dialog,'response'),Gtk::RESPONSE_CANCEL);
	$dialog->cancel->set_sensitive(FALSE);
	$dialog->cancel->set_label(_('Close'));
	$dialog->show_all();
	
	$dialog->status->append_text(sprintf("<b>%s</b>\n",_('uninstalling selected packages')));	
	
	while(Gtk::events_pending() || Gdk::events_pending()) { Gtk::main_iteration(); }
	katepkg_main_waste(10);
	
	//. begin uninstall.
	foreach($selected as $pkg) {
		$status = TRUE;
		$dialog->status->append_text(sprintf("\t%s... ",$pkg));
		$dialog->progress->set_text(sprintf("%s %s",_('uninstalling'),$pkg));
		while(Gtk::events_pending() || Gdk::events_pending()) { Gtk::main_iteration(); }
		
		$pp = popen(sprintf("export LANG=en_US; pkg -r \"%s\" --nodeps --no-colors 2>&1",$pkg),"r");
		while($dump = fgets($pp)) {
			if(preg_match("/^ERROR/",$dump)) {
				katepkg_dprintf("%s\n",$dump);
				$status = FALSE;
				++$errc;
			}
		}
		pclose($pp);
		
		if(!$status) {
			$dialog->status->append_text(sprintf("%s\n",_('failed')),TRUE);
		} else {
			$dialog->status->append_text(sprintf("%s\n",_('done')),TRUE);
		}

		$dialog->progress->set_fraction((++$opiter / $opcount));
		while(Gtk::events_pending() || Gdk::events_pending()) { Gtk::main_iteration(); }		
		
	}

	//. change window to reflect status.
	if($errc > 0) {
		$dialog->icon->set_from_file(EXECROOT."/share/pixmaps/katepkg/uninstallation_error.png");
		$dialog->progress->set_text(_('done with errors'));
	} else {
		$dialog->progress->set_text(_('all packages successfully removed'));
	}
	
	while(Gtk::events_pending() || Gdk::events_pending()) { Gtk::main_iteration(); }

	$selected = array();
	package_list_installed();
	
	$dialog->cancel->set_sensitive(TRUE);
	
	$dialog->run();
	
	$dialog->destroy(); $dialog = FALSE;
	
	$w->ui->set_sensitive(TRUE);
		
}

?>